// Set the dimensions and margins of the graph
const margin = { top: 20, right: 30, bottom: 30, left: 50 },
  width = 960 - margin.left - margin.right,
  height = 500 - margin.top - margin.bottom;

// Append the svg object to the body of the page
const svg = d3
  .select('svg')
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

// Parse the date / time
const parseTime = d3.timeParse('%Y-%m-%d');

// Set the ranges
const x = d3.scaleTime().range([0, width]);
const y = d3.scaleLinear().range([height, 0]);

// Define the area generator
const area = d3
  .area()
  .x(function (d) {
    return x(d.date);
  })
  .y0(height)
  .y1(function (d) {
    return y(d.value);
  });

// Get the data
d3.csv(
  'https://gist.githubusercontent.com/Sannihitha23/faf91a04c857700e4eb32addfb11b6cc/raw/a53a16a38d0a94a0585741f2e179c18ac7234a8c/music_data.csv',
  function (d) {
    return { date: parseTime(d.Date), value: +d.Value };
  },
).then(function (data) {
  // Scale the range of the data
  x.domain(d3.extent(data, (d) => d.date));
  y.domain([0, d3.max(data, (d) => d.value)]);

  // Add the area
  svg
    .append('path')
    .data([data])
    .attr('class', 'area')
    .attr('d', area);

  // Add the X Axis
  svg
    .append('g')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(x));

  // Add the Y Axis
  svg.append('g').call(d3.axisLeft(y));
});
